<?php
/**
 * Risa functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 * 
 * @package Risa
 * @since Risa 1.0
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since Risa 1.0
 */
if ( ! isset( $content_width ) ) {
	$content_width = 660;
}

/**
 * Risa only works in WordPress 4.1 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '4.1-alpha', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
}

if ( ! function_exists( 'risa_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 *
 * @since Risa 1.0
 */
function risa_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on risa, use a find and replace
	 * to change 'risa' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'risa', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * See: https://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 825, 510, true );

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu',      'risa' ),
		'social'  => __( 'Social Links Menu', 'risa' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link', 'gallery', 'status', 'audio', 'chat'
	) );

	$color_scheme  = risa_get_color_scheme();
	$default_color = trim( $color_scheme[0], '#' );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'risa_custom_background_args', array(
		'default-color'      => $default_color,
		'default-attachment' => 'fixed',
	) ) );

	add_theme_support('custom-logo');
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', 'genericons/genericons.css', risa_fonts_url() ) );
}
endif; // risa_setup
add_action( 'after_setup_theme', 'risa_setup' );

/**
 * Register widget area.
 *
 * @since Risa 1.0
 *
 * @link https://codex.wordpress.org/Function_Reference/register_sidebar
 */
function risa_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Widget Area', 'risa' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar.', 'risa' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'risa_widgets_init' );

if ( ! function_exists( 'risa_fonts_url' ) ) :
/**
 * Register Google fonts for Risa.
 *
 * @since Risa 1.0
 *
 * @return string Google fonts URL for the theme.
 */
function risa_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	/*
	 * Translators: If there are characters in your language that are not supported
	 * by Rosario, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Rosario font: on or off', 'risa' ) ) {
		$fonts[] = 'Rosario:400italic,700italic,400,700';
	}

	/*
	 * Translators: If there are characters in your language that are not supported
	 * by Amethysta, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Amethysta font: on or off', 'risa' ) ) {
		$fonts[] = 'Amethysta:400italic,700italic,400,700';
	}

	/*
	 * Translators: If there are characters in your language that are not supported
	 * by Inconsolata, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Inconsolata font: on or off', 'risa' ) ) {
		$fonts[] = 'Inconsolata:400,700';
	}

	/*
	 * Translators: To add an additional character subset specific to your language,
	 * translate this to 'greek', 'cyrillic', 'devanagari' or 'vietnamese'. Do not translate into your own language.
	 */
	$subset = _x( 'no-subset', 'Add new subset (greek, cyrillic, devanagari, vietnamese)', 'risa' );

	if ( 'cyrillic' == $subset ) {
		$subsets .= ',cyrillic,cyrillic-ext';
	} elseif ( 'greek' == $subset ) {
		$subsets .= ',greek,greek-ext';
	} elseif ( 'devanagari' == $subset ) {
		$subsets .= ',devanagari';
	} elseif ( 'vietnamese' == $subset ) {
		$subsets .= ',vietnamese';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}

	return $fonts_url;
}
endif;

/**
 * JavaScript Detection.
 *
 * Adds a `js` class to the root `<html>` element when JavaScript is detected.
 *
 * @since Risa 1.1
 */
function risa_javascript_detection() {
	echo "<script>(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);</script>\n";
}
add_action( 'wp_head', 'risa_javascript_detection', 0 );

/**
 * Enqueue scripts and styles.
 *
 * @since Risa 1.0
 */
function risa_scripts() {
	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'risa-fonts', risa_fonts_url(), array(), null );

	// Add Genericons, used in the main stylesheet.
	wp_enqueue_style( 'genericons', get_template_directory_uri() . '/genericons/genericons.css', array(), '3.2' );

	// Load our main stylesheet.
	wp_enqueue_style( 'risa-style', get_stylesheet_uri() );

	// Load the Internet Explorer specific stylesheet.
	wp_enqueue_style( 'risa-ie', get_template_directory_uri() . '/css/ie.css', array( 'risa-style' ), '20141010' );
	wp_style_add_data( 'risa-ie', 'conditional', 'lt IE 9' );

	// Load the Internet Explorer 7 specific stylesheet.
	wp_enqueue_style( 'risa-ie7', get_template_directory_uri() . '/css/ie7.css', array( 'risa-style' ), '20141010' );
	wp_style_add_data( 'risa-ie7', 'conditional', 'lt IE 8' );

	wp_enqueue_script( 'risa-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20141010', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_enqueue_script( 'risa-fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array(), '20141010', true );

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'risa-keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20141010' );
	}
	wp_enqueue_script( 'risa-social-share', get_template_directory_uri() . '/js/social-share.js', array( 'jquery' ), '20150330', true );

	wp_enqueue_script( 'risa-script', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), '20160610', true );

	wp_localize_script( 'risa-script', 'screenReaderText', array(
		'expand'   => '<span class="screen-reader-text">' . __( 'expand child menu', 'risa' ) . '</span>',
		'collapse' => '<span class="screen-reader-text">' . __( 'collapse child menu', 'risa' ) . '</span>',
	) );
}
add_action( 'wp_enqueue_scripts', 'risa_scripts' );

/**
 * Add featured image as background image to post navigation elements.
 *
 * @since Risa 1.0
 *
 * @see wp_add_inline_style()
 */
function risa_post_nav_background() {
	if ( ! is_single() ) {
		return;
	}

	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );
	$css      = '';

	if ( is_attachment() && 'attachment' == $previous->post_type ) {
		return;
	}

	if ( $previous &&  has_post_thumbnail( $previous->ID ) ) {
		$prevthumb = wp_get_attachment_image_src( get_post_thumbnail_id( $previous->ID ), 'post-thumbnail' );
		$css .= '
			.post-navigation .nav-previous { background-image: url(' . esc_url( $prevthumb[0] ) . '); }
			.post-navigation .nav-previous .post-title, .post-navigation .nav-previous a:hover .post-title, .post-navigation .nav-previous .meta-nav { color: #fff; }
			.post-navigation .nav-previous a:before { background-color: rgba(0, 0, 0, 0.4); }
		';
	}

	if ( $next && has_post_thumbnail( $next->ID ) ) {
		$nextthumb = wp_get_attachment_image_src( get_post_thumbnail_id( $next->ID ), 'post-thumbnail' );
		$css .= '
			.post-navigation .nav-next { background-image: url(' . esc_url( $nextthumb[0] ) . '); border-top: 0; }
			.post-navigation .nav-next .post-title, .post-navigation .nav-next a:hover .post-title, .post-navigation .nav-next .meta-nav { color: #fff; }
			.post-navigation .nav-next a:before { background-color: rgba(0, 0, 0, 0.4); }
		';
	}

	wp_add_inline_style( 'risa-style', $css );
}
//add_action( 'wp_enqueue_scripts', 'risa_post_nav_background' );

/**
 * Display descriptions in main navigation.
 *
 * @since Risa 1.0
 *
 * @param string  $item_output The menu item output.
 * @param WP_Post $item        Menu item object.
 * @param int     $depth       Depth of the menu.
 * @param array   $args        wp_nav_menu() arguments.
 * @return string Menu item with possible description.
 */
function risa_nav_description( $item_output, $item, $depth, $args ) {
	if ( 'primary' == $args->theme_location && $item->description ) {
		$item_output = str_replace( $args->link_after . '</a>', '<div class="menu-item-description">' . $item->description . '</div>' . $args->link_after . '</a>', $item_output );
	}

	return $item_output;
}
add_filter( 'walker_nav_menu_start_el', 'risa_nav_description', 10, 4 );

/**
 * Add a `screen-reader-text` class to the search form's submit button.
 *
 * @since Risa 1.0
 *
 * @param string $html Search form HTML.
 * @return string Modified search form HTML.
 */
function risa_search_form_modify( $html ) {
	//return str_replace( 'class="search-submit"', 'class="search-submit screen-reader-text"', $html );
	return str_replace( 'Search &hellip;', esc_attr_x( 'Type search here &hellip;', 'placeholder', 'risa' ), $html );

}
add_filter( 'get_search_form', 'risa_search_form_modify' );


/**
 * Setup a font controls & settings for Easy Google Fonts plugin (if installed)
 *
 * @since Risa 1.0
 *
 * @param array $options Default control list by the plugin.
 * @return array Modified $options parameter to applied in filter 'tt_font_get_option_parameters'.
 */
function risa_easy_google_fonts($options) {

	// Just replace all the plugin default font control

	unset(  $options['tt_default_body'],
			$options['tt_default_heading_2'],
			$options['tt_default_heading_3'],
			$options['tt_default_heading_4'],
			$options['tt_default_heading_5'],
			$options['tt_default_heading_6'],
			$options['tt_default_heading_1']
		);

	$new_options = array(
		
		'risa_default_body' => array(
			'name'        => 'risa_default_body',
			'title'       => __( 'Body & Paragraphs', 'risa' ),
			'description' => __( "Please select a font for the theme's body and paragraph text", 'risa' ),
			'properties'  => array( 'selector' => apply_filters( 'risa_default_body', 'body, button, input, select, textarea, blockquote cite, .entry-footer' ) ),
		),

		'risa_default_heading' => array(
			'name'        => 'risa_default_heading',
			'title'       => __( 'Headings', 'risa' ),
			'description' => __( "Please select a font for the theme's headings styles", 'risa' ),
			'properties'  => array( 'selector' => apply_filters( 'risa_default_heading', 'h1, h2, h3, h4, h5, h6, .widget .widget-title, .entry-footer .cat-links, .site-featured-posts .slider-nav .featured-title, .site-header .site-title, .site-footer .site-title, button, input[type="button"], input[type="reset"], input[type="submit"], .comment-form label, blockquote' ) ),
		),

		'risa_default_menu' => array(
			'name'        => 'risa_default_menu',
			'title'       => __( 'Menu', 'risa' ),
			'description' => __( "Please select a font for the theme's menu styles", 'risa' ),
			'properties'  => array( 'selector' => apply_filters( 'risa_default_menu', '.main-navigation' ) ),
		),

		'risa_default_entry_title' => array(
			'name'        => 'risa_default_entry_title',
			'title'       => __( 'Entry Title', 'risa' ),
			'description' => __( "Please select a font for the theme's Entry title styles", 'risa' ),
			'properties'  => array( 'selector' => apply_filters( 'risa_default_entry_title', '.entry-title, .post-navigation .post-title' ) ),
		),

		'risa_default_entry_meta' => array(
			'name'        => 'risa_default_entry_meta',
			'title'       => __( 'Entry Meta', 'risa' ),
			'description' => __( "Please select a font for the theme's Entry meta styles", 'risa' ),
			'properties'  => array( 'selector' => apply_filters( 'risa_default_entry_meta', '.entry-header .entry-meta, .entry-footer' ) ),
		),

		'risa_default_widget_title' => array(
			'name'        => 'risa_default_widget_title',
			'title'       => __( 'Widget Title', 'risa' ),
			'description' => __( "Please select a font for the theme's Widget title styles", 'risa' ),
			'properties'  => array( 'selector' => apply_filters( 'risa_default_widget_title', '.widget-title, .comments-title, .comment-reply-title' ) ),
		),

	);

	return array_merge( $options, $new_options);
}
add_filter( 'tt_font_get_option_parameters', 'risa_easy_google_fonts', 10 , 1 );

/**
 * Setup for installation of plugins required and recommended by the theme
 *
 * @since Risa 1.0
 *
 */
function risa_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		// The theme required oAuth Twitter Feed for Developers plugin for the twitter widget.
		array(
			'name'               => 'oAuth Twitter Feed for Developers', 
			'slug'               => 'oauth-twitter-feed-for-developers', 
			'required'           => true, 
		),

		// The theme recommend the Easy Google Fonts selection plugin.
		array(
			'name'               => 'Easy Google Fonts', 
			'slug'               => 'easy-google-fonts', 
			'required'           => false, 
		),

		// The theme recommend the Optin forms.
		array(
			'name'               => 'Optin Forms', 
			'slug'               => 'optin-forms', 
			'required'           => false, 
		),

	);

	$config = array(
		'id'           => 'risa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}
add_action( 'tgmpa_register', 'risa_register_required_plugins' );

/**
 * Social share script
 *
 * @since Risa 1.0
 */
function risa_social_share_script(){
	global $post;

	$thumb_id = get_post_thumbnail_id();
	$thumb_url_array = wp_get_attachment_image_src($thumb_id, 'full', true);
	$thumb_url = $thumb_url_array[0];

	if ( is_single() ) :
		remove_filter('excerpt_more', 'risa_excerpt_more');
		?>
		<script type="text/javascript">
			jQuery(document).ready(function($){
				$('.share').ShareLink({
						title: <?php echo json_encode(get_the_title()); ?>,
						text: <?php echo json_encode(get_the_excerpt()); ?>,
						image: <?php echo json_encode($thumb_url); ?>,
						url: <?php echo json_encode(get_permalink()); ?>
					});

				$('.counter').ShareCounter({
					url: '<?php echo get_the_permalink(); ?>'
				});
			});
		</script>

		<?php
		add_filter('excerpt_more', 'risa_excerpt_more');
	endif;
}
//add_action('wp_footer', 'risa_social_share_script');



/**
 * Implement the Custom Header feature.
 *
 * @since Risa 1.0
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 *
 * @since Risa 1.0
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 *
 * @since Risa 1.0
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Twitter Widget.
 *
 * @since Risa 1.0
 */
require get_template_directory() . '/inc/widgets/twitter.php';

/**
 * Posts Widget.
 *
 * @since Risa 1.0
 */
require get_template_directory() . '/inc/widgets/recent-posts.php';

/**
 * TGMPA Library.
 *
 * @since Risa 1.0
 */
require_once get_template_directory() . '/inc/tgm-plugin-activation/class-tgm-plugin-activation.php';
